@@ -29,6 +29,11 @@ from .common import (
     session_check_name,
 )
 
+if t.TYPE_CHECKING:
+    from typing_extensions import TypeAlias
+
+    DashLiteral: TypeAlias = t.Literal["-"]
+
 logger = logging.getLogger(__name__)
 
 
@@ -138,9 +143,9 @@ class Server(EnvironmentMixin):
         """
         try:
             res = self.cmd("list-sessions")
-            return res.returncode == 0
         except Exception:
             return False
+        return res.returncode == 0
 
     def raise_if_dead(self) -> None:
         """Raise if server not connected.
@@ -164,7 +169,7 @@ class Server(EnvironmentMixin):
         if self.config_file:
             cmd_args.insert(0, f"-f{self.config_file}")
 
-        subprocess.check_call([tmux_bin] + cmd_args)
+        subprocess.check_call([tmux_bin, *cmd_args])
 
     #
     # Command
@@ -188,7 +193,6 @@ class Server(EnvironmentMixin):
 
             Renamed from ``.tmux`` to ``.cmd``.
         """
-
         cmd_args: t.List[t.Union[str, int]] = list(args)
         if self.socket_name:
             cmd_args.insert(0, f"-L{self.socket_name}")
@@ -202,7 +206,7 @@ class Server(EnvironmentMixin):
             elif self.colors == 88:
                 cmd_args.insert(0, "-8")
             else:
-                raise ValueError("Server.colors must equal 88 or 256")
+                raise exc.UnknownColorOption()
 
         return tmux_cmd(*cmd_args, **kwargs)
 
@@ -222,7 +226,7 @@ class Server(EnvironmentMixin):
         """
         try:
             sessions = self.sessions
-            attached_sessions = list()
+            attached_sessions = []
 
             for session in sessions:
                 attached = session.session_attached
@@ -233,10 +237,9 @@ class Server(EnvironmentMixin):
                 else:
                     continue
 
-            return attached_sessions
-            # return [Session(**s) for s in attached_sessions] or None
         except Exception:
             return []
+        return attached_sessions
 
     def has_session(self, target_session: str, exact: bool = True) -> bool:
         """
@@ -334,7 +337,7 @@ class Server(EnvironmentMixin):
         """
         session_check_name(target_session)
 
-        tmux_args: t.Tuple[str, ...] = tuple()
+        tmux_args: t.Tuple[str, ...] = ()
         if target_session:
             tmux_args += ("-t%s" % target_session,)
 
@@ -351,6 +354,8 @@ class Server(EnvironmentMixin):
         start_directory: t.Optional[str] = None,
         window_name: t.Optional[str] = None,
         window_command: t.Optional[str] = None,
+        x: t.Optional[t.Union[int, "DashLiteral"]] = None,
+        y: t.Optional[t.Union[int, "DashLiteral"]] = None,
         *args: t.Any,
         **kwargs: t.Any,
     ) -> Session:
@@ -388,11 +393,17 @@ class Server(EnvironmentMixin):
             ::
 
                 $ tmux new-session -n <window_name>
-        window_command : str
+        window_command : str, optional
             execute a command on starting the session.  The window will close
             when the command exits. NOTE: When this command exits the window
             will close.  This feature is useful for long-running processes
             where the closing of the window upon completion is desired.
+        x : [int, str], optional
+            Force the specified width instead of the tmux default for a
+            dettached session
+        y : [int, str], optional
+            Force the specified height instead of the tmux default for a
+            dettached session
 
         Returns
         -------
@@ -455,10 +466,11 @@ class Server(EnvironmentMixin):
         if window_name:
             tmux_args += ("-n", window_name)
 
-        # tmux 2.6 gives unattached sessions a tiny default area
-        # no need send in -x/-y if they're in a client already, though
-        if has_gte_version("2.6") and "TMUX" not in os.environ:
-            tmux_args += ("-x", 800, "-y", 600)
+        if x is not None:
+            tmux_args += ("-x", x)
+
+        if y is not None:
+            tmux_args += ("-y", y)
 
         if window_command:
             tmux_args += (window_command,)
@@ -499,7 +511,7 @@ class Server(EnvironmentMixin):
                 list_cmd="list-sessions",
                 server=self,
             ):
-                sessions.append(Session(server=self, **obj))
+                sessions.append(Session(server=self, **obj))  # noqa: PERF401
         except Exception:
             pass
 
@@ -513,13 +525,14 @@ class Server(EnvironmentMixin):
         :meth:`.windows.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.windows.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        windows: t.List["Window"] = []
-        for obj in fetch_objs(
-            list_cmd="list-windows",
-            list_extra_args=("-a",),
-            server=self,
-        ):
-            windows.append(Window(server=self, **obj))
+        windows: t.List["Window"] = [
+            Window(server=self, **obj)
+            for obj in fetch_objs(
+                list_cmd="list-windows",
+                list_extra_args=("-a",),
+                server=self,
+            )
+        ]
 
         return QueryList(windows)
 
@@ -531,13 +544,14 @@ class Server(EnvironmentMixin):
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.panes.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        panes: t.List["Pane"] = []
-        for obj in fetch_objs(
-            list_cmd="list-panes",
-            list_extra_args=["-s"],
-            server=self,
-        ):
-            panes.append(Pane(server=self, **obj))
+        panes: t.List["Pane"] = [
+            Pane(server=self, **obj)
+            for obj in fetch_objs(
+                list_cmd="list-panes",
+                list_extra_args=["-s"],
+                server=self,
+            )
+        ]
 
         return QueryList(panes)
 
@@ -545,23 +559,23 @@ class Server(EnvironmentMixin):
     # Dunder
     #
     def __eq__(self, other: object) -> bool:
-        assert isinstance(other, Server)
-        return (
-            self.socket_name == other.socket_name
-            and self.socket_path == other.socket_path
-        )
+        """Equal operator for :class:`Server` object."""
+        if isinstance(other, Server):
+            return (
+                self.socket_name == other.socket_name
+                and self.socket_path == other.socket_path
+            )
+        return False
 
     def __repr__(self) -> str:
+        """Representation of :class:`Server` object."""
         if self.socket_name is not None:
             return (
                 f"{self.__class__.__name__}"
                 f"(socket_name={getattr(self, 'socket_name', 'default')})"
             )
         elif self.socket_path is not None:
-            return (
-                f"{self.__class__.__name__}"
-                f"(socket_path={getattr(self, 'socket_path')})"
-            )
+            return f"{self.__class__.__name__}" f"(socket_path={self.socket_path})"
         return f"{self.__class__.__name__}" f"(socket_path=/tmp/tmux-1000/default)"
 
     #
@@ -577,8 +591,11 @@ class Server(EnvironmentMixin):
         :class:`util.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
 
         .. deprecated:: 0.16
+
+           Deprecated in favor of :attr:`.panes`.
+
         """
-        warnings.warn("Server._list_panes() is deprecated")
+        warnings.warn("Server._list_panes() is deprecated", stacklevel=2)
         return [p.__dict__ for p in self.panes]
 
     def _update_panes(self) -> "Server":
@@ -590,33 +607,48 @@ class Server(EnvironmentMixin):
         :class:`Server`
 
         .. deprecated:: 0.16
+
+           Deprecated in favor of :attr:`.panes` and returning ``self``.
+
         """
-        warnings.warn("Server._update_panes() is deprecated")
+        warnings.warn("Server._update_panes() is deprecated", stacklevel=2)
         self._list_panes()
         return self
 
     def get_by_id(self, id: str) -> t.Optional[Session]:
-        """
+        """Return session by id. Deprecated in favor of :meth:`.sessions.get()`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.sessions.get()`.
+
         """
-        warnings.warn("Server.get_by_id() is deprecated")
+        warnings.warn("Server.get_by_id() is deprecated", stacklevel=2)
         return self.sessions.get(session_id=id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Session]:
-        """
+        """Filter through sessions, return list of :class:`Session`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.session.filter()`.
+
         """
-        warnings.warn("Server.find_where() is deprecated")
+        warnings.warn("Server.find_where() is deprecated", stacklevel=2)
         try:
             return self.sessions.filter(**kwargs)
         except IndexError:
             return []
 
     def find_where(self, kwargs: t.Dict[str, t.Any]) -> t.Optional[Session]:
-        """
+        """Filter through sessions, return first :class:`Session`.
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :meth:`.sessions.get()`.
+
         """
-        warnings.warn("Server.find_where() is deprecated")
+        warnings.warn("Server.find_where() is deprecated", stacklevel=2)
         return self.sessions.get(default=None, **kwargs)
 
     def _list_windows(self) -> t.List[WindowDict]:
@@ -628,16 +660,22 @@ class Server(EnvironmentMixin):
         :class:`common.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.windows`.
+
         """
-        warnings.warn("Server._list_windows() is deprecated")
+        warnings.warn("Server._list_windows() is deprecated", stacklevel=2)
         return [w.__dict__ for w in self.windows]
 
     def _update_windows(self) -> "Server":
         """Update internal window data and return ``self`` for chainability.
 
         .. deprecated:: 0.16
+
+           Deprecated in favor of :attr:`.windows` and returning ``self``.
+
         """
-        warnings.warn("Server._update_windows() is deprecated")
+        warnings.warn("Server._update_windows() is deprecated", stacklevel=2)
         self._list_windows()
         return self
 
@@ -646,15 +684,21 @@ class Server(EnvironmentMixin):
         """Property / alias to return :meth:`~._list_sessions`.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.sessions`.
+
         """
-        warnings.warn("Server._sessions is deprecated")
+        warnings.warn("Server._sessions is deprecated", stacklevel=2)
         return self._list_sessions()
 
     def _list_sessions(self) -> t.List["SessionDict"]:
-        """
+        """Return list of session object dictionaries.
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.sessions`.
         """
-        warnings.warn("Server._list_sessions() is deprecated")
+        warnings.warn("Server._list_sessions() is deprecated", stacklevel=2)
         return [s.__dict__ for s in self.sessions]
 
     def list_sessions(self) -> t.List[Session]:
@@ -662,18 +706,23 @@ class Server(EnvironmentMixin):
 
         .. deprecated:: 0.16
 
+           Slated to be removed in favor of :attr:`.sessions`.
+
         Returns
         -------
         list of :class:`Session`
         """
-        warnings.warn("Server.list_sessions is deprecated")
+        warnings.warn("Server.list_sessions is deprecated", stacklevel=2)
         return self.sessions
 
     @property
     def children(self) -> QueryList["Session"]:  # type:ignore
-        """Was used by TmuxRelationalObject (but that's longer used in this class)
+        """Was used by TmuxRelationalObject (but that's longer used in this class).
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.sessions`.
+
         """
-        warnings.warn("Server.children is deprecated")
+        warnings.warn("Server.children is deprecated", stacklevel=2)
         return self.sessions
