@@ -42,19 +42,17 @@ def test_find_where(server: Server, session: Session) -> None:
 
 def test_find_where_None(server: Server, session: Session) -> None:
     """.find_where returns None if no results found."""
-
     while True:
-        nonexistant_session = TEST_SESSION_PREFIX + next(namer)
+        nonexistent_session = TEST_SESSION_PREFIX + next(namer)
 
-        if not server.has_session(nonexistant_session):
+        if not server.has_session(nonexistent_session):
             break
 
-    assert len(server.sessions.filter(session_name=nonexistant_session)) == 0
+    assert len(server.sessions.filter(session_name=nonexistent_session)) == 0
 
 
 def test_find_where_multiple_infos(server: Server, session: Session) -> None:
     """.find_where returns objects with multiple attributes."""
-
     for session in server.sessions:
         session_id = session.session_id
         assert session_id is not None
@@ -97,7 +95,6 @@ def test_find_where_multiple_infos(server: Server, session: Session) -> None:
 
 def test_where(server: Server, session: Session) -> None:
     """Test self.where() returns matching objects."""
-
     window = session.attached_window
     window.split_window()  # create second pane
 
@@ -151,7 +148,6 @@ def test_where(server: Server, session: Session) -> None:
 
 def test_filter(server: Server) -> None:
     """Test self.filter() retrieves child object."""
-
     sess = server.new_session("test")
     window = sess.attached_window
 
